## Contact me
[Test pypi](https://test.pypi.org/project/NewLifeUtils/5.0.1/)

[Real pypi 5.0.1](https://pypi.org/project/NewLifeUtils/5.0.1/)
[Real pypi 5.0.2](https://pypi.org/project/NewLifeUtils/5.0.2/)

[My website](http://newlife-learn.h1n.ru)

[My vk](https://vk.com/newlife2019_szhs)

My Mail: [semechkagent@gmail.com](semechkagent@gmail.com)


# NewLifeUtils
## Recent change
The main preparation of all files for collaboration with github is completed. Now I can continue developing the ported code with github's participation. Over time, I will add full documentation and a lot of useful features

## About the project
In fact, there is active development, repeated rewriting of the code. All actions are published on github for orderly storage of changes and fixing all my actions. I don't encourage you to use my code. My goal is to learn how to write programs beautifully and learn how to use github. If you have any ideas, criticism, or suggestions , I'm happy to listen
Now this is the 5th attempt to rewrite the code beautifully, each time I change the very structure of the code. In General, I didn't really study the language features, so my code will be disgusting to a professional programmer. Maybe someday I will achieve the effect that I need

## Project idea.
Simplify the development of some elements of more significant and large projects with ready-made features. I'm not ready to use external Python modules, besides, it's better to write something yourself and experiment, gain experience. In the future, I will not publish such children's content on such a large platform. I'm just learning

## Plans and current changes
In fact, there are quite a lot of them, but they are constantly changing, I just don't have the strength to constantly change something in a bunch of files at the same time

## Current plans
In progress... you can look at projects

## Old Table
| Module name  |  Description  |  Status       |
| ------------ | ------------- | ------------- |
| `ColorModule`          | Provides color output capabilities |  **Complete**  |
| `LoggerModule`         | Provides the ability to display information in an orderly manner on the screen  |  **Complete**  |
| `StringUtilModule`     | Module with additional options for processing and converting strings  |  **Complete**  |
| `ExceptModule`         | An additional module for working with errors during the execution of your code   |  **Complete**  |
| `CustomShellModule`    | CustomShellModule is a module that automates user input and output, creates the right          development environment, and provides the right API |  **Complete**  |
| `TableBuildModule`     | Module for working with tables, displaying them on the screen and arranging them inside the table itself |  **Complete**  |
| `UtilsModule`          | List of various other functions and add-ons that are not included in the above modules  |  **Complete**  |
| `FileModule`           | Wrapper module for simplified file management |  **Complete**  |
| `FilelogModule`        | Add-on for working with logs |  **Complete**  |
| `DatabaseManageModule` | A specialized class for working with databases and data inside them. It allows you to simplify working with them as much as possible, but due to  size of the original API, it does not allow you to implement absolutely all functions, so this class also provides access to direct database management     |  **Complete**  |
| `RandomModule`         | A module that provides a redesigned API for working with pseudo-random numbers  |  **Working**  |


***Translator used**